==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Form_DataTable.pm <==
package WebGUI::i18n::Spanish::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1253714268',
    'message' => 'Nueva Columna'
  },
  'Value' => {
    'lastUpdated' => '1253714274',
    'message' => 'Valor'
  },
  'add column' => {
    'lastUpdated' => '1227111692',
    'message' => 'Agregar Columna'
  },
  'add row' => {
    'lastUpdated' => '1227111704',
    'message' => 'Agregar Fila'
  },
  'cancel' => {
    'lastUpdated' => '1227111717',
    'message' => 'Cancelar'
  },
  'delete column' => {
    'lastUpdated' => '1227111735',
    'message' => 'Eliminar Columna'
  },
  'delete confirm' => {
    'lastUpdated' => '1227111773',
    'message' => '&iquest;Est&aacute; seguro que desea eliminar esas filas?'
  },
  'delete rows' => {
    'lastUpdated' => '1227111791',
    'message' => 'Eliminar Filas Seleccionadas'
  },
  'edit schema' => {
    'lastUpdated' => '1227111805',
    'message' => 'Editar Esquema'
  },
  'format date' => {
    'lastUpdated' => '1227111820',
    'message' => 'Fecha'
  },
  'format email' => {
    'lastUpdated' => '1227111834',
    'message' => 'E-Mail'
  },
  'format link' => {
    'lastUpdated' => '1227111856',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1227111882',
    'message' => 'Num&eacute;rico'
  },
  'format text' => {
    'lastUpdated' => '1227111894',
    'message' => 'Texto'
  },
  'help' => {
    'lastUpdated' => '1227111908',
    'message' => 'Ayuda'
  },
  'help add row' => {
    'lastUpdated' => '1227111945',
    'message' => 'El bot&oacute;n Agregar Fila, agregar&aacute; una fila al final de la tabla.'
  },
  'help default sort' => {
    'lastUpdated' => '1227111971',
    'message' => 'La tabla ser&aacute; ordenada exactamente en la forma en que es almacenada.'
  },
  'help edit cell' => {
    'lastUpdated' => '1227112025',
    'message' => 'Realice un click doble sobre cualquier celda para editarla. Oprimir el tabulador (TAB) almacena los cambios en la celda actual y se mueve a la siguiente.'
  },
  'help reorder column' => {
    'lastUpdated' => '1227112066',
    'message' => 'Arrastre las columnas y col&oacute;quelas en su sitio para reorganizarlas.'
  },
  'help select row' => {
    'lastUpdated' => '1227112104',
    'message' => 'Haga click sobre una fila para seleccionarla. Utilize Shift o Control para seleccionar m&aacute;s de una fila.'
  },
  'ok' => {
    'lastUpdated' => '1227112116',
    'message' => 'Ok'
  },
  'save' => {
    'lastUpdated' => '1227112129',
    'message' => 'Guardar'
  },
  'save failure' => {
    'lastUpdated' => '1227112150',
    'message' => '&iexcl;Imposible guardar! Intente de nuevo.'
  },
  'save success' => {
    'lastUpdated' => '1227112171',
    'message' => '&iexcl;Cambios guardados exitosamente!'
  },
  'topicName' => {
    'lastUpdated' => '1227112189',
    'message' => 'Tabla de Datos'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Form_DataTable.pm <==
package WebGUI::i18n::Spanish::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1253714268',
    'message' => 'Nueva Columna'
  },
  'Value' => {
    'lastUpdated' => '1253714274',
    'message' => 'Valor'
  },
  'add column' => {
    'lastUpdated' => '1227111692',
    'message' => 'Agregar Columna'
  },
  'add row' => {
    'lastUpdated' => '1227111704',
    'message' => 'Agregar Fila'
  },
  'cancel' => {
    'lastUpdated' => '1227111717',
    'message' => 'Cancelar'
  },
  'data error' => {
    'lastUpdated' => '1317823636',
    'message' => 'Error de datos.'
  },
  'delete column' => {
    'lastUpdated' => '1227111735',
    'message' => 'Eliminar Columna'
  },
  'delete confirm' => {
    'lastUpdated' => '1227111773',
    'message' => '&iquest;Est&aacute; seguro que desea eliminar esas filas?'
  },
  'delete rows' => {
    'lastUpdated' => '1227111791',
    'message' => 'Eliminar Filas Seleccionadas'
  },
  'edit schema' => {
    'lastUpdated' => '1227111805',
    'message' => 'Editar Esquema'
  },
  'format date' => {
    'lastUpdated' => '1227111820',
    'message' => 'Fecha'
  },
  'format email' => {
    'lastUpdated' => '1227111834',
    'message' => 'E-Mail'
  },
  'format htmlarea' => {
    'lastUpdated' => '1317823643',
    'message' => 'Area HTML'
  },
  'format link' => {
    'lastUpdated' => '1227111856',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1227111882',
    'message' => 'Num&eacute;rico'
  },
  'format text' => {
    'lastUpdated' => '1227111894',
    'message' => 'Texto'
  },
  'format textarea' => {
    'lastUpdated' => '1317823649',
    'message' => 'Area de Texto'
  },
  'help' => {
    'lastUpdated' => '1227111908',
    'message' => 'Ayuda'
  },
  'help add row' => {
    'lastUpdated' => '1227111945',
    'message' => 'El bot&oacute;n Agregar Fila, agregar&aacute; una fila al final de la tabla.'
  },
  'help default sort' => {
    'lastUpdated' => '1227111971',
    'message' => 'La tabla ser&aacute; ordenada exactamente en la forma en que es almacenada.'
  },
  'help edit cell' => {
    'lastUpdated' => '1227112025',
    'message' => 'Realice un click doble sobre cualquier celda para editarla. Oprimir el tabulador (TAB) almacena los cambios en la celda actual y se mueve a la siguiente.'
  },
  'help reorder column' => {
    'lastUpdated' => '1227112066',
    'message' => 'Arrastre las columnas y col&oacute;quelas en su sitio para reorganizarlas.'
  },
  'help select row' => {
    'lastUpdated' => '1227112104',
    'message' => 'Haga click sobre una fila para seleccionarla. Utilize Shift o Control para seleccionar m&aacute;s de una fila.'
  },
  'ok' => {
    'lastUpdated' => '1227112116',
    'message' => 'Ok'
  },
  'save' => {
    'lastUpdated' => '1227112129',
    'message' => 'Guardar'
  },
  'save failure' => {
    'lastUpdated' => '1227112150',
    'message' => '&iexcl;Imposible guardar! Intente de nuevo.'
  },
  'save success' => {
    'lastUpdated' => '1227112171',
    'message' => '&iexcl;Cambios guardados exitosamente!'
  },
  'sort ascending' => {
    'lastUpdated' => '1317823690',
    'message' => 'Click para orden ascendente'
  },
  'sort descending' => {
    'lastUpdated' => '1317823698',
    'message' => 'Click para orden descendente'
  },
  'topicName' => {
    'lastUpdated' => '1227112189',
    'message' => 'Tabla de Datos'
  }
}
;

1;
